@@ -1,10 +1,10 @@
 /*
  * ndisc.c - ICMPv6 neighbour discovery command line tool
- * $Id: ndisc.c 483 2007-08-08 15:09:36Z remi $
+ * $Id: ndisc.c 528 2007-11-03 12:26:47Z remi $
  */
 
 /*************************************************************************
- *  Copyright © 2004-2006 Rémi Denis-Courmont.                           *
+ *  Copyright © 2004-2007 Rémi Denis-Courmont.                           *
  *  This program is free software: you can redistribute and/or modify    *
  *  it under the terms of the GNU General Public License as published by *
  *  the Free Software Foundation, versions 2 or 3 of the license.        *
@@ -501,7 +501,7 @@ parseadv (const uint8_t *buf, size_t len, const struct sockaddr_in6 *tgt,
 				parseroute (ptr);
 				break;
 
-			case 25: // RFC Ed queued draft-jeong-dnsop-ipv6-dns-discovery-12
+			case 25: // RFC5006
 				parserdnss (ptr);
 				break;
 		}
@@ -767,16 +767,16 @@ static int
 version (void)
 {
 	printf (_(
-"ndisc6: IPv6 Neighbor/Router Discovery userland tool %s (%s)\n"), VERSION, "$Rev: 483 $");
+"ndisc6: IPv6 Neighbor/Router Discovery userland tool %s (%s)\n"), VERSION, "$Rev: 528 $");
 	printf (_(" built %s on %s\n"), __DATE__, PACKAGE_BUILD_HOSTNAME);
 
 	printf (_("Configured with: %s\n"), PACKAGE_CONFIGURE_INVOCATION);
 	puts (_("Written by Remi Denis-Courmont\n"));
 
-	printf (_("Copyright (C) %u-%u Remi Denis-Courmont\n"
-"This is free software; see the source for copying conditions.\n"
-"There is NO warranty; not even for MERCHANTABILITY or\n"
-"FITNESS FOR A PARTICULAR PURPOSE.\n"), 2004, 2006);
+	printf (_("Copyright (C) %u-%u Remi Denis-Courmont\n"), 2004, 2007);
+	puts (_("This is free software; see the source for copying conditions.\n"
+	        "There is NO warranty; not even for MERCHANTABILITY or\n"
+	        "FITNESS FOR A PARTICULAR PURPOSE.\n"));
 	return 0;
 }
 
