@@ -1,10 +1,10 @@
 /*
  * traceroute.c - TCP/IPv6 traceroute tool
- * $Id: traceroute.c 483 2007-08-08 15:09:36Z remi $
+ * $Id: traceroute.c 583 2008-01-10 18:04:55Z remi $
  */
 
 /*************************************************************************
- *  Copyright © 2005-2006 Rémi Denis-Courmont.                           *
+ *  Copyright © 2005-2007 Rémi Denis-Courmont.                           *
  *  This program is free software: you can redistribute and/or modify    *
  *  it under the terms of the GNU General Public License as published by *
  *  the Free Software Foundation, versions 2 or 3 of the license.        *
@@ -48,6 +48,9 @@
 #ifdef HAVE_GETOPT_H
 # include <getopt.h>
 #endif
+#ifdef __linux__
+# include <linux/filter.h>
+#endif
 
 #include "gettime.h"
 #include "inet6rth.h"
@@ -1007,6 +1010,48 @@ traceroute (const char *dsthost, const char *dstport,
 		goto error;
 	printf (_("%u hops max, "), max_ttl);
 
+#ifdef SO_ATTACH_FILTER
+	{
+		/* Static socket filter for the unconnected ICMPv6 socket.
+		* We are only interested if the inner IPv6 packet has the
+		* right IPv6 destination */
+		struct sock_filter f[10], *pc = f;
+		struct sock_fprog sfp = {
+			.len = sizeof (f) / sizeof (f[0]),
+			.filter = f,
+		};
+
+		for (unsigned i = 0; i < 4; i++)
+		{
+			/* A = icmp->ip6_dst.s6_addr32[i]; */
+			pc->code = BPF_LD + BPF_W + BPF_ABS;
+			pc->jt = pc->jf = 0;
+			pc->k = 8 + 24 + (i * 4);
+			pc++;
+
+			/* if (A != dst.sin6_addr.s6_addr32[i]) goto drop; */
+			pc->code = BPF_JMP + BPF_JEQ + BPF_K;
+			pc->jt = 0;
+			pc->jf = f + (sizeof (f) / sizeof (f[0])) - (pc + 2);
+			pc->k = ntohl (dst.sin6_addr.s6_addr32[i]);
+			pc++;
+		}
+
+		/* return ~0U; */
+		pc->code = BPF_RET + BPF_K;
+		pc->jt = pc->jf = 0;
+		pc->k = ~0U;
+		pc++;
+
+		/* drop: return 0; */
+		pc->code = BPF_RET + BPF_K;
+		pc->jt = pc->jf = pc->k = 0;
+
+		assert ((++pc - f) == (sizeof (f) / sizeof (f[0])));
+		setsockopt (icmpfd, SOL_SOCKET, SO_ATTACH_FILTER, &sfp, sizeof (sfp));
+	}
+#endif
+
 	/* Adjusts packets length */
 	size_t overhead = sizeof (struct ip6_hdr);
 	if (rt_segc > 0)
@@ -1204,15 +1249,15 @@ static int
 version (void)
 {
 	printf (_(
-"traceroute6: TCP & UDP IPv6 traceroute tool %s (%s)\n"), VERSION, "$Rev: 483 $");
+"traceroute6: TCP & UDP IPv6 traceroute tool %s (%s)\n"), VERSION, "$Rev: 583 $");
 	printf (_(" built %s on %s\n"), __DATE__, PACKAGE_BUILD_HOSTNAME);
 	printf (_("Configured with: %s\n"), PACKAGE_CONFIGURE_INVOCATION);
 	puts (_("Written by Remi Denis-Courmont\n"));
 
-	printf (_("Copyright (C) %u-%u Remi Denis-Courmont\n"
-"This is free software; see the source for copying conditions.\n"
-"There is NO warranty; not even for MERCHANTABILITY or\n"
-"FITNESS FOR A PARTICULAR PURPOSE.\n"), 2005, 2006);
+	printf (_("Copyright (C) %u-%u Remi Denis-Courmont\n"), 2005, 2007);
+	puts (_("This is free software; see the source for copying conditions.\n"
+	        "There is NO warranty; not even for MERCHANTABILITY or\n"
+	        "FITNESS FOR A PARTICULAR PURPOSE.\n"));
 	return 0;
 }
 
